class SourceInformation:
    def __init__(self, source_uuid, source_number, source_name, source_device):
        self.source_uuid = source_uuid
        self.source_number = source_number
        self.source_name = source_name
        self.source_device = source_device
